@@ -1,12 +1,16 @@
 package Elive::Entity::MeetingParameters;
 use warnings; use strict;
 
+use Mouse;
+
+use Elive::Entity;
 use base qw{ Elive::Entity };
-use Moose;
 
 __PACKAGE__->entity_name('MeetingParameters');
 
-has 'meetingId' => (is => 'rw', isa => 'Pkey', required => 1, documentation => 'meeting (foreign-key)');
+has 'meetingId' => (is => 'rw', isa => 'Int', required => 1);
+__PACKAGE__->primary_key('meetingId');
+
 has 'costCenter' => (is => 'rw', isa => 'Str');
 has 'moderatorNotes' => (is => 'rw', isa => 'Str');
 has 'userNotes' => (is => 'rw', isa => 'Str');
@@ -27,8 +31,31 @@ Elive::Entity::MeetingParameters - meeting parameters entity class
 
 =head1 DESCRIPTION
 
-This class contains additional meeting information. Note that this entity
-is automatically created when you create a meeting.
+This class contains additional meeting information.
+
+=cut
+
+=head1 METHODS
+
+=cut
+
+=head2 create
+
+The create method is not applicable. The meeting parameters table is
+automatically created when you create a table.
+
+=cut
+
+sub create {shift->_not_available}
+
+=head2 list
+
+The list method is not available for meeting parameters. You'll need
+to retrieve on a meeting id.
+
+=cut
+
+sub list {shift->_not_available}
 
 =head1 See Also
 
